FeinCMS Integration — django-markupmirror 0.1a2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-markupmirror 0.1a2 documentation »

# FeinCMS Integration

django-markupmirror provides easy integration with Feinheit’s FeinCMS in form of a custom content-type.

The only thing you need to do to use it, is to register the `MarkupMirrorContent` content-type model with your `Page` configuration:

    from feincms.module.page.models import Page
    from markupmirror.feincms.models import MarkupMirrorContent

    Page.create_content_type(MarkupMirrorContent)

After that you should synchronize your database structure. Find out how to use South to migrate your FeinCMS tables in FeinCMS’ documentation.

### Navigation

- index
- modules |
- next |
- previous |
- django-markupmirror 0.1a2 documentation »